/**
  *  \file flakconf.h
  *  \brief FLAK Configuration
  *
  *  This contains the FLAK configuration structure which is needed in
  *  addition to the normal host configuration (PConfig).
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef FLAKCONF_H_INCLUDED
#define FLAKCONF_H_INCLUDED

class Stream;

/** FLAK Configuration Structure. This contains the FLAK-specific
    configuration settings. Its members correspond 1:1 to the
    configuration file entries. */
struct FlakConfig {
    int   RatingBeamScale;
    int   RatingTorpScale;
    int   RatingBayScale;
    int   RatingMassScale;
    int   RatingPEBonus;
    int   RatingFullAttackBonus;
    int   RatingRandomBonus;

    int   StartingDistanceShip;        // FIXME: close to edge of 16-bit limit
    int   StartingDistancePlanet;      // FIXME: close to edge of 16-bit limit
    int   StartingDistancePerPlayer;
    int   StartingDistancePerFleet;

    int   CompensationShipScale;
    int   CompensationBeamScale;
    int   CompensationTorpScale;
    int   CompensationFighterScale;
    int   CompensationLimit;
    int   CompensationMass100KTScale;
    int   CompensationAdjust;

    int   CyborgDebrisRate;

    int   MaximumFleetSize;

    bool  SendUtildata;
};

extern FlakConfig flak_config;

void initFlakConfig();
void loadFlakConfig(Stream& file, bool in_section);

// flakmod.cc, only available in PCC2-based build:
void loadFlakConfig();
extern const struct ModuleInitializer mod_flak[];

#endif
