/**
  *  \file game/cspec.h
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_CSPEC_H
#define PCC_V2_GAME_CSPEC_H

#include "cpluslib/string.h"
#include "cpluslib/types.h"
#include "game/cargotype.h"
#include "game/cost.h"

/** Cargo specification. A cargo specification contains an amount of
    - N/T/D/M
    - money, supplies
    - colonists
    - fighters, torps

    This is used by the script interface. It is closely related to
    GCost, which stores a cost consisting of T/D/M/sup/mc only. Having
    both separate frees GCost users from having to deal with the other
    types. */
class GCargoSpec {
 public:
    GCargoSpec();
    GCargoSpec(const GCost&);
    GCargoSpec(const string_t& str, bool acceptMax);

    GCargoSpec& operator+=(const GCargoSpec& other);
    GCargoSpec& operator-=(const GCargoSpec& other);
    GCargoSpec& operator*=(int32_t count);

    string_t toPHostString() const;
    string_t toCargoSpecString() const;
    GCost    toCost() const;

    bool    parse(const string_t& str, bool acceptMax);
    void    set(GCargoType t, int32_t amount);
    int32_t get(GCargoType t) const;
    void    add(GCargoType t, int32_t amount);
    void    remove(GCargoType t, int32_t amount);
    void    clear();
    bool    isEnoughFor(const GCargoSpec& other) const;
    bool    isValid() const;
    bool    isEmpty() const;
    void    doSupplySale();

    bool    divide(int32_t n);
    bool    divide(const GCargoSpec& cs, int32_t& result) const;

    static bool isValidType(GCargoType t);
    static int charToCargoType(char c);

 private:
    enum { MAX = el_Torps+1 };
    int32_t amounts[MAX];
};

#endif
