/**
  *  \file util/pluginmgr.h
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UTIL_PLUGINMGR_H
#define PCC_V2_UTIL_PLUGINMGR_H

#include "util/plugin.h"
#include "cpluslib/ptrvector.h"
#include "io/dirs.h"

class PluginManager {
 public:
    PluginManager();
    ~PluginManager();

    static PluginManager& getInstance();

    void findPlugins(Directory& dir);

    void findPlugins(string_t dirName);

    void addNewPlugin(Plugin* p);

    void enumPlugins(std::vector<Plugin*>& out, bool ordered = true) const;

    void enumConflictingPlugins(const Plugin& candidate, std::vector<Plugin*>& out) const;

    void enumDependingPlugins(const Plugin& candidate, std::vector<Plugin*>& out) const;

    void enumFeatures(Plugin::FeatureSet& fset) const;

    Plugin* extractPlugin(Plugin* p);

    Plugin* getPluginById(const string_t& id) const;

 private:
    ptr_vector<Plugin> plugins;
};

#endif
